pub struct RaylibFrontend<S, D> { /* private fields */ }Expand description
The main struct that implements the frontend capabilities.
Implementations
Sourceimpl<S, D> RaylibFrontend<S, D>
impl<S, D> RaylibFrontend<S, D>
Sourcepub fn new(
automaton: Automaton<S, D>,
update_rate: Duration,
cell_margin: u32,
window_size: (u32, u32),
) -> Self
pub fn new( automaton: Automaton<S, D>, update_rate: Duration, cell_margin: u32, window_size: (u32, u32), ) -> Self
Instantiates the frontend.
You may want to use FrontendBuilder for convenience.
Sourcepub fn window_should_close(&self) -> bool
pub fn window_should_close(&self) -> bool
Checks if the window should close (e.g. esc pressed).
Sourcepub fn tick(&mut self) -> Option<ExecutionState>
pub fn tick(&mut self) -> Option<ExecutionState>
Updates the inner timer to compute the next generation
according to the update rate (see
FrontendBuilder::update_rate()).
Sourcepub fn step(&mut self) -> ExecutionState
pub fn step(&mut self) -> ExecutionState
Computes the next generation of the automaton immediately.
See tick() for properly timed updating.
Sourcepub fn default_key_actions(&mut self)
pub fn default_key_actions(&mut self)
Registers default key actions:
- Space -> Pause
- LMB -> Toggle cell under cursor
Sourceimpl<S: RenderCell<Color>, D> RaylibFrontend<S, D>
impl<S: RenderCell<Color>, D> RaylibFrontend<S, D>
Sourcepub fn display_grid(&mut self)
pub fn display_grid(&mut self)
Displays the cell grid using Raylib.
Manages the job of clearing the background and drawing all the
cells with respect to their RenderCell implementation.